package com.ruoyi.business.mapper;

import java.util.List;
import com.ruoyi.business.domain.HwAlarmRule;

/**
 * 报警规则Mapper接口
 * 
 * @author xins
 * @date 2023-09-16
 */
public interface HwAlarmRuleMapper 
{
    /**
     * 查询报警规则
     * 
     * @param alarmRuleId 报警规则主键
     * @return 报警规则
     */
    public HwAlarmRule selectHwAlarmRuleByAlarmRuleId(Long alarmRuleId);

    /**
     * 查询报警规则列表
     * 
     * @param hwAlarmRule 报警规则
     * @return 报警规则集合
     */
    public List<HwAlarmRule> selectHwAlarmRuleList(HwAlarmRule hwAlarmRule);

    /**
     * 新增报警规则
     * 
     * @param hwAlarmRule 报警规则
     * @return 结果
     */
    public int insertHwAlarmRule(HwAlarmRule hwAlarmRule);

    /**
     * 修改报警规则
     * 
     * @param hwAlarmRule 报警规则
     * @return 结果
     */
    public int updateHwAlarmRule(HwAlarmRule hwAlarmRule);

    /**
     * 删除报警规则
     * 
     * @param alarmRuleId 报警规则主键
     * @return 结果
     */
    public int deleteHwAlarmRuleByAlarmRuleId(Long alarmRuleId);

    /**
     * 批量删除报警规则
     * 
     * @param alarmRuleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHwAlarmRuleByAlarmRuleIds(Long[] alarmRuleIds);
}
